{% extends "admin/change_list.html" %}
{% load i18n admin_urls %}

{% block extrastyle %}
{{ block.super }}
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.7.2/css/all.min.css">
{% endblock %}

{% block object-tools-items %}
    <li>
        <a href="{% url 'admin:chat-compose' %}" class="addlink">
            <i class="fas fa-pen-to-square"></i> {% translate "Compose Message" %}
        </a>
    </li>
{% endblock %} 